@@ -73,6 +73,13 @@ def validate_gitops_syntax(gitops):
                     "components.index.homepage", checks, item, ok
                 )
 
+        # footerLogos is optional, but when present, it must be an array (list)
+        footerLogos = components.get("footerLogos", [])
+        ok = ok and assert_and_log(
+            isinstance(footerLogos, list),
+            FieldError("footerLogos must be an array if presents in the config"),
+        )
+
     explorer_enabled = gitops.get("featureFlags", {}).get("explorer", True)
     explorerconfig = gitops.get("explorerConfig")
     configs = []
